summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/info_bubble.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/views/info_bubble.h')
-rw-r--r--chrome/browser/views/info_bubble.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/views/info_bubble.h b/chrome/browser/views/info_bubble.h
index ee4a2b3..8678428 100644
--- a/chrome/browser/views/info_bubble.h
+++ b/chrome/browser/views/info_bubble.h
@@ -42,7 +42,7 @@
// (or rather ContentView) insets the content view for you, so that the
// content typically shouldn't have any additional margins around the view.
-class ChromeFrame;
+class BrowserWindow;
class InfoBubble;
class InfoBubbleDelegate {
@@ -174,8 +174,8 @@ class InfoBubble : public ChromeViews::HWNDViewContainer,
// Creates and return a new ContentView containing content.
virtual ContentView* CreateContentView(ChromeViews::View* content);
- // Returns the ChromeFrame that owns this InfoBubble.
- ChromeFrame* GetHostingFrame();
+ // Returns the BrowserWindow that owns this InfoBubble.
+ BrowserWindow* GetHostingWindow();
private:
// The delegate notified when the InfoBubble is closed.